==> lucia-auth-0.2.0.tgz: package/auth/index.js <==
import { authenticateUserFunction, createUserFunction, deleteUserFunction, getUserFunction, getUserByProviderIdFunction, updateUserAttributesFunction, updateUserPasswordFunction, updateUserProviderIdFunction } from "./user/index.js";
import { validateRequestHeadersFunction } from "./request.js";
import { createSessionFunction, deleteDeadUserSessionsFunction, renewSessionFunction, invalidateAllUserSessionsFunction, validateSessionFunction, validateSessionUserFunction, invalidateSessionFunction, getSessionFunction, generateSessionIdFunction, getSessionUserFunction } from "./session.js";
import { createSessionCookiesFunction } from "./cookie.js";
import { logError } from "../utils/log.js";
export { SESSION_COOKIE_NAME } from "./cookie.js";
export const lucia = (configs) => {
    return new Auth(configs);
};
const validateConfigurations = (configs) => {
    const isAdapterIdentified = !configs.adapter;
    if (isAdapterIdentified) {
        logError('Adapter is not defined in configuration ("config.adapter")');
        process.exit(1);
    }
};
export class Auth {
    configs;
    constructor(configs) {
        validateConfigurations(configs);
        const defaultCookieOption = {
            sameSite: "lax",
            path: "/"
        };
        this.configs = {
            adapter: "user" in configs.adapter
                ? { ...configs.adapter.user, ...configs.adapter.session }
                : configs.adapter,
            generateCustomUserId: configs.generateCustomUserId || (async () => null),
            env: configs.env,
            csrfProtection: configs.csrfProtection || true,
            sessionTimeout: configs.sessionTimeout || 1000 * 60 * 60 * 24,
            idlePeriodTimeout: configs.idlePeriodTimeout || 1000 * 60 * 60 * 24 * 14,
            transformUserData: ({ id, hashed_password, provider_id, ...attributes }) => {
                const transform = configs.transformUserData ||
                    (({ id }) => {
                        return {
                            userId: id
                        };
                    });
                return transform({ id, ...attributes });
            },
            sessionCookieOptions: configs.sessionCookieOptions || [defaultCookieOption],
            deleteCookieOptions: configs.deleteCookieOptions || []
        };
        this.getUser = getUserFunction(this);
        this.getUserByProviderId = getUserByProviderIdFunction(this);
        this.getSessionUser = getSessionUserFunction(this);
        this.createUser = createUserFunction(this);
        this.updateUserAttributes = updateUserAttributesFunction(this);
        this.updateUserProviderId = updateUserProviderIdFunction(this);
        this.updateUserPassword = updateUserPasswordFunction(this);
        this.deleteUser = deleteUserFunction(this);
        this.authenticateUser = authenticateUserFunction(this);
        this.getSession = getSessionFunction(this);
        this.validateSession = validateSessionFunction(this);
        this.validateSessionUser = validateSessionUserFunction(this);
        this.generateSessionId = generateSessionIdFunction(this);
        this.createSession = createSessionFunction(this);
        this.renewSession = renewSessionFunction(this);
        this.invalidateSession = invalidateSessionFunction(this);
        this.invalidateAllUserSessions = invalidateAllUserSessionsFunction(this);
        this.deleteDeadUserSessions = deleteDeadUserSessionsFunction(this);
        this.validateRequestHeaders = validateRequestHeadersFunction(this);
        this.createSessionCookies = createSessionCookiesFunction(this);
    }
    getUser;
    getUserByProviderId;
    getSessionUser;
    createUser;
    updateUserAttributes;
    updateUserProviderId;
    updateUserPassword;
    deleteUser;
    authenticateUser;
    getSession;
    validateSession;
    validateSessionUser;
    generateSessionId;
    createSession;
    renewSession;
    invalidateSession;
    invalidateAllUserSessions;
    deleteDeadUserSessions;
    validateRequestHeaders;
    createSessionCookies;
}

==> lucia-auth-0.2.2.tgz: package/auth/index.js <==
import { authenticateUserFunction, createUserFunction, deleteUserFunction, getUserFunction, getUserByProviderIdFunction, updateUserAttributesFunction, updateUserPasswordFunction, updateUserProviderIdFunction } from "./user/index.js";
import { validateRequestHeadersFunction } from "./request.js";
import { createSessionFunction, deleteDeadUserSessionsFunction, renewSessionFunction, invalidateAllUserSessionsFunction, validateSessionFunction, validateSessionUserFunction, invalidateSessionFunction, getSessionFunction, generateSessionIdFunction, getSessionUserFunction } from "./session.js";
import { createSessionCookiesFunction } from "./cookie.js";
import { logError } from "../utils/log.js";
import { generateHashWithScrypt, validateHash } from "../utils/crypto.js";
export { SESSION_COOKIE_NAME } from "./cookie.js";
export const lucia = (configs) => {
    return new Auth(configs);
};
const validateConfigurations = (configs) => {
    const isAdapterIdentified = !configs.adapter;
    if (isAdapterIdentified) {
        logError('Adapter is not defined in configuration ("config.adapter")');
        process.exit(1);
    }
};
export class Auth {
    configs;
    constructor(configs) {
        validateConfigurations(configs);
        const defaultCookieOption = {
            sameSite: "lax",
            path: "/"
        };
        if ("user" in configs.adapter) {
            if ("getSessionAndUserBySessionId" in configs.adapter.user) {
                delete configs.adapter.user.getSessionAndUserBySessionId;
            }
            if ("getSessionAndUserBySessionId" in configs.adapter.session) {
                delete configs.adapter.session.getSessionAndUserBySessionId;
            }
        }
        const adapter = "user" in configs.adapter
            ? { ...configs.adapter.user, ...configs.adapter.session }
            : configs.adapter;
        this.configs = {
            adapter,
            generateCustomUserId: configs.generateCustomUserId || (async () => null),
            env: configs.env,
            csrfProtection: configs.csrfProtection || true,
            sessionTimeout: configs.sessionTimeout || 1000 * 60 * 60 * 24,
            idlePeriodTimeout: configs.idlePeriodTimeout || 1000 * 60 * 60 * 24 * 14,
            transformUserData: ({ id, hashed_password, provider_id, ...attributes }) => {
                const transform = configs.transformUserData ||
                    (({ id }) => {
                        return {
                            userId: id
                        };
                    });
                return transform({ id, ...attributes });
            },
            sessionCookieOptions: configs.sessionCookieOptions || [defaultCookieOption],
            deleteCookieOptions: configs.deleteCookieOptions || [],
            hash: {
                generate: configs.hash?.generate ?? generateHashWithScrypt,
                validate: configs.hash?.validate ?? validateHash
            }
        };
        this.getUser = getUserFunction(this);
        this.getUserByProviderId = getUserByProviderIdFunction(this);
        this.getSessionUser = getSessionUserFunction(this);
        this.createUser = createUserFunction(this);
        this.updateUserAttributes = updateUserAttributesFunction(this);
        this.updateUserProviderId = updateUserProviderIdFunction(this);
        this.updateUserPassword = updateUserPasswordFunction(this);
        this.deleteUser = deleteUserFunction(this);
        this.authenticateUser = authenticateUserFunction(this);
        this.getSession = getSessionFunction(this);
        this.validateSession = validateSessionFunction(this);
        this.validateSessionUser = validateSessionUserFunction(this);
        this.generateSessionId = generateSessionIdFunction(this);
        this.createSession = createSessionFunction(this);
        this.renewSession = renewSessionFunction(this);
        this.invalidateSession = invalidateSessionFunction(this);
        this.invalidateAllUserSessions = invalidateAllUserSessionsFunction(this);
        this.deleteDeadUserSessions = deleteDeadUserSessionsFunction(this);
        this.validateRequestHeaders = validateRequestHeadersFunction(this);
        this.createSessionCookies = createSessionCookiesFunction(this);
    }
    getUser;
    getUserByProviderId;
    getSessionUser;
    createUser;
    updateUserAttributes;
    updateUserProviderId;
    updateUserPassword;
    deleteUser;
    authenticateUser;
    getSession;
    validateSession;
    validateSessionUser;
    generateSessionId;
    createSession;
    renewSession;
    invalidateSession;
    invalidateAllUserSessions;
    deleteDeadUserSessions;
    validateRequestHeaders;
    createSessionCookies;
}
